CCL: ccl_spline_params Struct Reference

CCL

Data Fields
ccl_spline_params Struct Reference

`#include <ccl_params.h>`

## Data Fields
double | A_SPLINE_DELTA
int | A_SPLINE_NA
double | A_SPLINE_MIN
double | A_SPLINE_MAX
double | LOGM_SPLINE_DELTA
int | LOGM_SPLINE_NM
double | LOGM_SPLINE_MIN
double | LOGM_SPLINE_MAX
int | N_A
double | K_MAX_SPLINE
double | K_MAX
double | K_MIN_DEFAULT
int | N_K

## Detailed Description

Struct that contains all the parameters needed to create certain splines. This includes splines for the scale factor, masses, and power spectra.

## Field Documentation

## ◆ A_SPLINE_DELTA

double ccl_spline_params::A_SPLINE_DELTA

## ◆ A_SPLINE_MAX

double ccl_spline_params::A_SPLINE_MAX

## ◆ A_SPLINE_MIN

double ccl_spline_params::A_SPLINE_MIN

## ◆ A_SPLINE_NA

int ccl_spline_params::A_SPLINE_NA

## ◆ K_MAX

double ccl_spline_params::K_MAX

## ◆ K_MAX_SPLINE

double ccl_spline_params::K_MAX_SPLINE

## ◆ K_MIN_DEFAULT

double ccl_spline_params::K_MIN_DEFAULT

## ◆ LOGM_SPLINE_DELTA

double ccl_spline_params::LOGM_SPLINE_DELTA

## ◆ LOGM_SPLINE_MAX

double ccl_spline_params::LOGM_SPLINE_MAX

## ◆ LOGM_SPLINE_MIN

double ccl_spline_params::LOGM_SPLINE_MIN

## ◆ LOGM_SPLINE_NM

int ccl_spline_params::LOGM_SPLINE_NM

## ◆ N_A

int ccl_spline_params::N_A

## ◆ N_K

int ccl_spline_params::N_K

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_params.h